@@ -8,6 +8,7 @@
 #include "GVApi.h"
 #include "NotifyGVContactsTable.h"
 #include "NotifyGVInbox.h"
+#include "dbusinterface/qgvn_proxy.h"
 
 class MainWindow : public QObject
 {
@@ -17,7 +18,8 @@ public:
     MainWindow(QObject *parent = 0);
 
 private slots:
-    void doWork ();
+    void init();
+    void doWork();
     void setStatus(const QString &strText, int timeout  = 3000);
     void loginCompleted (AsyncTaskToken *token);
     void logoutCompleted (AsyncTaskToken *token);
@@ -25,6 +27,9 @@ private slots:
     void inboxChanged ();
     void dailyTimeout();
 
+    void getOut();
+    void onCommandForClient(const QString &command);
+
 private:
     void doLogin ();
     void doLogout ();
@@ -37,20 +42,23 @@ private:
     //! THE API
     GVApi           gvApi;
 
+    //! Path for the settings ini
+    QString         strIni;
+
     // Settings parsed from the ini file
-    QString strUser;
-    QString strPass;
+    QString         strUser;
+    QString         strPass;
 
     // Frequency of checking in seconds
-    quint8 checkTimeout;
+    quint8          checkTimeout;
 
     // Mosquitto settings
-    QString m_strMqServer;
-    int m_mqPort;
-    QString m_strMqTopic;
+    QString         m_strMqServer;
+    int             m_mqPort;
+    QString         m_strMqTopic;
 
     //! Are we logged in yet?
-    bool bIsLoggedIn;
+    bool            bIsLoggedIn;
 
     //! GV Contacts object
     GVContactsTable oContacts;
@@ -62,6 +70,9 @@ private:
 
     //! Number of times we checked
     quint64         checkCounter;
+
+    //! Object for DBus client
+    QGVNotifyProxyIface *client;
 };
 
 #endif //_MAINWINDOW_H_
