@@ -96,7 +96,7 @@ MainWindow::MainWindow (QWidget *parent)
     if (!rv) { exit(1); }
 
     // Schedule the init a bit later so that the app.exec() can begin executing
-    QTimer::singleShot (100, this, SLOT (init()));
+    QTimer::singleShot (10, this, SLOT (init()));
 }//MainWindow::MainWindow
 
 MainWindow::~MainWindow ()
@@ -406,6 +406,9 @@ MainWindow::initQML ()
     ctx->setContextProperty ("g_wMul", wMul);
     ctx->setContextProperty ("g_fontMul", fontMul);
 
+    ctx->setContextProperty ("g_IsMobilePlatform",
+                             MOBILE_OS ? !bTempFalse : bTempFalse);
+
     // Initialize the QML view
     this->setSource (QUrl(osd.getMainQML()));
 
@@ -480,10 +483,20 @@ MainWindow::initQML ()
                   &oContacts, SLOT(refreshContacts()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL (sigRefreshAllContacts()),
+                  &oContacts, SLOT(refreshAllContacts()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
     rv = connect (gObj, SIGNAL(sigRefreshInbox()),
                   &oInbox,   SLOT(refresh()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
+    rv = connect (gObj, SIGNAL(sigRefreshAllInbox()),
+                  &oInbox,  SLOT(refreshFullInbox()));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
     rv = connect (gObj, SIGNAL(sigHaptic()),
                   this, SLOT(onBtnClickFroHapticFeedback()));
     Q_ASSERT(rv);
